#!/bin/bash -e
#
# Copyright 2015 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

PATH="$PATH:/usr/share/univention-docker-dev/scripts"

ARCH=$(dpkg --print-architecture)

argv0="$0"
usage() {
	echo >&2 "usage: $argv0"
	exit 1
}

opttemp=$(getopt --options '+f' --longoptions 'force,help' --name "$argv0" -- "$@")
eval set -- "$opttemp"
unset opttemp

unset force
while true; do
	case "$1" in
		-f|--force)
			force=1
			shift
			;;
		--help)
			usage;
			;;
		--)
			shift;
			break
			;;
		*)
			usage;
			;;
	esac
done

if [ $# -gt 0 ]; then
	usage
fi

if [ "$force" = 1 ]; then
	for role in member slave master generic stem; do
		for version in latest 4.1-0; do
			docker rmi "univention/ucs-${role}-${ARCH}:${version}" || true
		done
	done
fi

### First build ucs-stem-${ARCH}:4.1-0
create-docker-ucs-stem-image.sh 4.1-0

### Then build the role layers
for role in member slave master generic; do
	create-docker-ucs-role-image.sh 4.1-0 "$role"
done

